pub struct WpFifoV1 { /* private fields */ }Expand description
fifo interface
A fifo object for a surface that may be used to add display refresh constraints to content updates.
See also the Request enum for this interface.